@@ -16,7 +16,6 @@ use std::borrow::Cow;
 use std::fmt::Display;
 use std::io::Write;
 use std::path::Path;
-use std::sync::Mutex;
 
 mod test;
 
@@ -62,8 +61,8 @@ impl Heading {
   }
 }
 
-pub struct ColoredPrinter<W: WriteColor + Send + Sync> {
-  writer: Mutex<W>,
+pub struct ColoredPrinter<W: WriteColor> {
+  writer: W,
   config: term::Config,
   styles: PrintStyles,
   heading: Heading,
@@ -76,10 +75,10 @@ impl ColoredPrinter<StandardStream> {
   }
 }
 
-impl<W: WriteColor + Send + Sync> ColoredPrinter<W> {
+impl<W: WriteColor> ColoredPrinter<W> {
   pub fn new(writer: W) -> Self {
     Self {
-      writer: Mutex::new(writer),
+      writer,
       styles: PrintStyles::from(ColorChoice::Auto),
       config: term::Config::default(),
       heading: Heading::Auto,
@@ -128,15 +127,15 @@ impl<W: WriteColor + Send + Sync> ColoredPrinter<W> {
   }
 }
 
-impl<W: WriteColor + Send + Sync> Printer for ColoredPrinter<W> {
+impl<W: WriteColor> Printer for ColoredPrinter<W> {
   fn print_rule<'a>(
-    &self,
+    &mut self,
     matches: Matches!('a),
     file: SimpleFile<Cow<str>, &String>,
     rule: &RuleConfig<SgLang>,
   ) -> Result<()> {
     let config = &self.config;
-    let mut writer = self.writer.lock().expect("should not fail");
+    let writer = &mut self.writer;
     let severity = match rule.severity {
       Severity::Error => diagnostic::Severity::Error,
       Severity::Warning => diagnostic::Severity::Warning,
@@ -163,7 +162,7 @@ impl<W: WriteColor + Send + Sync> Printer for ColoredPrinter<W> {
     Ok(())
   }
 
-  fn print_matches<'a>(&self, matches: Matches!('a), path: &Path) -> Result<()> {
+  fn print_matches<'a>(&mut self, matches: Matches!('a), path: &Path) -> Result<()> {
     if self.heading.should_print() {
       print_matches_with_heading(matches, path, self)
     } else {
@@ -171,18 +170,18 @@ impl<W: WriteColor + Send + Sync> Printer for ColoredPrinter<W> {
     }
   }
 
-  fn print_diffs<'a>(&self, diffs: Diffs!('a), path: &Path) -> Result<()> {
-    let writer = &mut *self.writer.lock().expect("should success");
+  fn print_diffs<'a>(&mut self, diffs: Diffs!('a), path: &Path) -> Result<()> {
     let context = self.diff_context();
+    let writer = &mut self.writer;
     print_diffs(diffs, path, &self.styles, writer, context)
   }
   fn print_rule_diffs(
-    &self,
+    &mut self,
     diffs: Vec<(Diff<'_>, &RuleConfig<SgLang>)>,
     path: &Path,
   ) -> Result<()> {
-    let writer = &mut *self.writer.lock().expect("should success");
     let context = self.diff_context();
+    let writer = &mut self.writer;
     let mut start = 0;
     print_prelude(path, &self.styles, writer)?;
     for (diff, rule) in diffs {
@@ -322,13 +321,14 @@ impl<'a> MatchMerger<'a> {
   }
 }
 
-fn print_matches_with_heading<'a, W: WriteColor + Send + Sync>(
+fn print_matches_with_heading<'a, W: WriteColor>(
   mut matches: Matches!('a),
   path: &Path,
-  printer: &ColoredPrinter<W>,
+  printer: &mut ColoredPrinter<W>,
 ) -> Result<()> {
   let styles = &printer.styles;
-  let writer = &mut *printer.writer.lock().expect("cannot get printer lock");
+  let context_span = printer.context_span();
+  let writer = &mut printer.writer;
   print_prelude(path, styles, writer)?;
   let Some(first_match) = matches.next() else {
     return Ok(());
@@ -360,7 +360,7 @@ fn print_matches_with_heading<'a, W: WriteColor + Send + Sync>(
     write!(writer, "{line_num:>width$}│")?; // initial line num
     print_highlight(ret.lines(), width, &mut num, writer, styles)?;
     writeln!(writer)?; // end match new line
-    if printer.context_span() > 0 {
+    if context_span > 0 {
       writeln!(writer, "{:╴>width$}┤", "")?; // make separation
     }
     merger.conclude_match(&nm);
@@ -379,13 +379,14 @@ fn print_matches_with_heading<'a, W: WriteColor + Send + Sync>(
   Ok(())
 }
 
-fn print_matches_with_prefix<'a, W: WriteColor + Send + Sync>(
+fn print_matches_with_prefix<'a, W: WriteColor>(
   mut matches: Matches!('a),
   path: &Path,
-  printer: &ColoredPrinter<W>,
+  printer: &mut ColoredPrinter<W>,
 ) -> Result<()> {
   let styles = &printer.styles;
-  let writer = &mut *printer.writer.lock().expect("cannot get printer lock");
+  let context_span = printer.context_span();
+  let writer = &mut printer.writer;
   let path = path.display();
   let Some(first_match) = matches.next() else {
     return Ok(());
@@ -412,7 +413,7 @@ fn print_matches_with_prefix<'a, W: WriteColor + Send + Sync>(
       let num = merger.last_start_line + n;
       writeln!(writer, "{path}:{num}:{line}")?;
     }
-    if printer.context_span() > 0 {
+    if context_span > 0 {
       writeln!(writer, "--")?; // make separation
     }
     merger.conclude_match(&nm);
