@@ -288,6 +288,7 @@ impl NoIgnore {
   }
 }
 
+/// CLI args to overwrite rule configuration
 #[derive(Args, Debug)]
 pub struct OverwriteArgs {
   /// Scan the codebase with rules with ids matching REGEX.
@@ -333,6 +334,13 @@ pub struct OverwriteArgs {
   pub off: Option<Vec<String>>,
 }
 
+impl OverwriteArgs {
+  /// Returns true if none rule is turned off on CLI nor filtered out
+  pub fn include_all_rules(&self) -> bool {
+    self.filter.is_none() && self.off.is_none()
+  }
+}
+
 #[cfg(test)]
 mod test {
   use super::*;
